==> huaweicloudsdkkafka-3.1.126-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/create_connector_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateConnectorResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_id': 'str',
        'connector_id': 'str'
    }

    attribute_map = {
        'job_id': 'job_id',
        'connector_id': 'connector_id'
    }

    def __init__(self, job_id=None, connector_id=None):
        """CreateConnectorResponse

        The model defined in huaweicloud sdk

        :param job_id: 任务ID。 
        :type job_id: str
        :param connector_id: 实例转储ID。 
        :type connector_id: str
        """
        
        super(CreateConnectorResponse, self).__init__()

        self._job_id = None
        self._connector_id = None
        self.discriminator = None

        if job_id is not None:
            self.job_id = job_id
        if connector_id is not None:
            self.connector_id = connector_id

    @property
    def job_id(self):
        """Gets the job_id of this CreateConnectorResponse.

        任务ID。 

        :return: The job_id of this CreateConnectorResponse.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this CreateConnectorResponse.

        任务ID。 

        :param job_id: The job_id of this CreateConnectorResponse.
        :type job_id: str
        """
        self._job_id = job_id

    @property
    def connector_id(self):
        """Gets the connector_id of this CreateConnectorResponse.

        实例转储ID。 

        :return: The connector_id of this CreateConnectorResponse.
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this CreateConnectorResponse.

        实例转储ID。 

        :param connector_id: The connector_id of this CreateConnectorResponse.
        :type connector_id: str
        """
        self._connector_id = connector_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConnectorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.1.151-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/create_connector_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateConnectorResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_id': 'str',
        'connector_id': 'str'
    }

    attribute_map = {
        'job_id': 'job_id',
        'connector_id': 'connector_id'
    }

    def __init__(self, job_id=None, connector_id=None):
        r"""CreateConnectorResponse

        The model defined in huaweicloud sdk

        :param job_id: 任务ID。 
        :type job_id: str
        :param connector_id: 实例转储ID。 
        :type connector_id: str
        """
        
        super(CreateConnectorResponse, self).__init__()

        self._job_id = None
        self._connector_id = None
        self.discriminator = None

        if job_id is not None:
            self.job_id = job_id
        if connector_id is not None:
            self.connector_id = connector_id

    @property
    def job_id(self):
        r"""Gets the job_id of this CreateConnectorResponse.

        任务ID。 

        :return: The job_id of this CreateConnectorResponse.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        r"""Sets the job_id of this CreateConnectorResponse.

        任务ID。 

        :param job_id: The job_id of this CreateConnectorResponse.
        :type job_id: str
        """
        self._job_id = job_id

    @property
    def connector_id(self):
        r"""Gets the connector_id of this CreateConnectorResponse.

        实例转储ID。 

        :return: The connector_id of this CreateConnectorResponse.
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        r"""Sets the connector_id of this CreateConnectorResponse.

        实例转储ID。 

        :param connector_id: The connector_id of this CreateConnectorResponse.
        :type connector_id: str
        """
        self._connector_id = connector_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConnectorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
